@@ -39,38 +39,49 @@
 /*----------------------------------------------------------------------*/
 /* Parser switch							*/
 /*----------------------------------------------------------------------*/
-/*
- * This is the linkage section of each parsers.
- * If you want to support new language, you must define two procedures:
- *	1. Initializing procedure.
+/**
+ * @details
+ * This is the linkage section of each parsers. <br>
+ * If you want to support new language, you must define two procedures: <br>
+ *	-# Initializing procedure (#init_proc).
  *		Called once first with an input file descripter.
- *	2. Executing procedure.
- *		Called repeatedly until returning EOF.
- *		It should read from above descripter and write HTML
+ *	-# Executing procedure (#exec_proc).
+ *		Called repeatedly until returning @NAME{EOF}. <br>
+ *		It should read from above descripter and write @NAME{HTML}
  *		using output procedures in this module.
  */
 struct lang_entry {
 	const char *lang_name;
-	void (*init_proc)(FILE *);		/* initializing procedure */
-	int (*exec_proc)(void);			/* executing procedure */
+	void (*init_proc)(FILE *);		/**< initializing procedure */
+	int (*exec_proc)(void);			/**< executing procedure */
 };
 
-/* initializing procedures */
+/**
+ * @name initializing procedures
+ * For lang_entry::init_proc
+ */
+/** @{ */
 void c_parser_init(FILE *);
 void yacc_parser_init(FILE *);
 void cpp_parser_init(FILE *);
 void java_parser_init(FILE *);
 void php_parser_init(FILE *);
 void asm_parser_init(FILE *);
+/** @} */
 
-/* executing procedures */
+/**
+ * @name executing procedures
+ * For lang_entry::exec_proc
+ */
+/** @{ */
 int c_lex(void);
 int cpp_lex(void);
 int java_lex(void);
 int php_lex(void);
 int asm_lex(void);
+/** @} */
 
-/*
+/**
  * The first entry is default language.
  */
 struct lang_entry lang_switch[] = {
@@ -84,11 +95,14 @@ struct lang_entry lang_switch[] = {
 };
 #define DEFAULT_ENTRY &lang_switch[0]
 
-/*
+/**
  * get language entry.
  *
- *	i)	lang	language name (NULL means 'not specified'.)
- *	r)		language entry
+ * If the specified language (@a lang) is not found, it assumes the
+ * default language, which is @NAME{C}.
+ *
+ *	@param[in]	lang	language name (@VAR{NULL} means 'not specified'.)
+ *	@return		language entry
  */
 static struct lang_entry *
 get_lang_entry(const char *lang)
@@ -124,20 +138,30 @@ static const char *curpfile;
 static int warned;
 static int last_lineno;
 
-/*
+/**
  * Put a character to HTML as is.
  *
- * You should use this function to put a control character.
+ * @note You should use this function to put a control character. <br>
+ *
+ * @attention
+ * No escaping of @CODE{'\<'}, @CODE{'\>'} and @CODE{'\&'} is performed.
+ *
+ * @see put_char()
  */
 void
 echoc(int c)
 {
         strbuf_putc(outbuf, c);
 }
-/*
+/**
  * Put a string to HTML as is.
  *
- * You should use this function to put a control sequence.
+ * @note You should use this function to put a control sequence.
+ *
+ * @attention
+ * No escaping of @CODE{'\<'}, @CODE{'\>'} and @CODE{'\&'} is performed.
+ *
+ * @see put_string()
  */
 void
 echos(const char *s)
@@ -147,8 +171,10 @@ echos(const char *s)
 /*----------------------------------------------------------------------*/
 /* HTML output								*/
 /*----------------------------------------------------------------------*/
-/*
+/**
  * Quote character with HTML's way.
+ *
+ * (Fixes @CODE{'\<'}, @CODE{'\>'} and @CODE{'\&'} for HTML).
  */
 static const char *
 HTML_quoting(int c)
@@ -161,12 +187,12 @@ HTML_quoting(int c)
 		return quote_amp;
 	return NULL;
 }
-/*
+/**
  * fill_anchor: fill anchor into file name
  *
- *       i)      $root   root or index page
- *       i)      $path   path name
- *       r)              hypertext file name string
+ *       @param[in]      root   \$root or index page
+ *       @param[in]      path   \$path name
+ *       @return              hypertext file name string
  */
 const char *
 fill_anchor(const char *root, const char *path)
@@ -202,12 +228,12 @@ fill_anchor(const char *root, const char *path)
         return strbuf_value(sb);
 }
 
-/*
+/**
  * link_format: make hypertext from anchor array.
  *
- *	i)	(previous, next, first, last, top, bottom)
+ *	@param[in]	ref	(previous, next, first, last, top, bottom) <br>
  *		-1: top, -2: bottom, other: line number
- *	r)	HTML
+ *	@return	HTML
  */
 const char *
 link_format(int ref[A_SIZE])
@@ -246,12 +272,13 @@ link_format(int ref[A_SIZE])
 	}
         return strbuf_value(sb);
 }
-/*
+/**
  * fixed_guide_link_format: make fixed guide
  *
- *	i)	(previous, next, first, last, top, bottom)
+ *	@param[in]	ref	(previous, next, first, last, top, bottom) <br>
  *		-1: top, -2: bottom, other: line number
- *	r)	HTML
+ *	@param[in]	anchors
+ *	@return	HTML
  */
 const char *
 fixed_guide_link_format(int ref[A_LIMIT], const char *anchors)
@@ -312,11 +339,11 @@ fixed_guide_link_format(int ref[A_LIMIT], const char *anchors)
 
 	return strbuf_value(sb);
 }
-/*
+/**
  * generate_guide: generate guide string for definition line.
  *
- *	i)	lineno	line number
- *	r)		guide string
+ *	@param[in]	lineno	line number
+ *	@return		guide string
  */
 const char *
 generate_guide(int lineno)
@@ -341,13 +368,16 @@ generate_guide(int lineno)
 
 	return strbuf_value(sb);
 }
-/*
+/**
  * tooltip: generate tooltip string
  *
- *	i)	type	I,R,Y,D,M
- *	i)	lno	line number
- *	i)	opt	
- *	r)		tooltip string
+ *	@param[in]	type	@CODE{'I'}: 'Included from' <br>
+ *			@CODE{'R'}: 'Defined at' <br>
+ *			@CODE{'Y'}: 'Used at' <br>
+ *			@CODE{'D'}, @CODE{'M'}: 'Referred from'
+ *	@param[in]	lno	line number
+ *	@param[in]	opt	
+ *	@return		tooltip string
  */
 const char *
 tooltip(int type, int lno, const char *opt)
@@ -388,12 +418,14 @@ tooltip(int type, int lno, const char *opt)
 	strbuf_putc(sb, '.');
 	return strbuf_value(sb);
 }
-/*
+/**
  * put_anchor: output HTML anchor.
  *
- *	i)	name	tag
- *	i)	type	tag type
- *	i)	lineno	current line no
+ *	@param[in]	name	tag
+ *	@param[in]	type	tag type. @CODE{'R'}: @NAME{GTAGS} <br>
+ *			@CODE{'Y'}: @NAME{GSYMS} <br>
+ *			@CODE{'D'}, @CODE{'M'}, @CODE{'T'}: @NAME{GRTAGS}
+ *	@param[in]	lineno	current line no
  */
 void
 put_anchor(char *name, int type, int lineno)
@@ -481,12 +513,14 @@ put_anchor(char *name, int type, int lineno)
 		}
 	}
 }
-/*
+/**
  * put_anchor_force: output HTML anchor without warning.
  *
- *	i)	name	tag
- *	i)	type	tag type
- *	i)	lineno	current line no
+ *	@param[in]	name	tag
+ *	@param[in]	length
+ *	@param[in]	lineno	current line no
+ *
+ * @remark The tag type is fixed at 'R' (@NAME{GTAGS})
  */
 void
 put_anchor_force(char *name, int length, int lineno)
@@ -500,11 +534,11 @@ put_anchor_force(char *name, int length, int lineno)
 	put_anchor(strbuf_value(sb), 'R', lineno);
 	wflag = saveflag;
 }
-/*
+/**
  * put_include_anchor: output HTML anchor.
  *
- *	i)	inc	inc structure
- *	i)	path	path name for display
+ *	@param[in]	inc	inc structure
+ *	@param[in]	path	path name for display
  */
 void
 put_include_anchor(struct data *inc, const char *path)
@@ -519,11 +553,11 @@ put_include_anchor(struct data *inc, const char *path)
 	strbuf_puts(outbuf, path);
 	strbuf_puts(outbuf, gen_href_end());
 }
-/*
+/**
  * put_include_anchor_direct: output HTML anchor.
  *
- *	i)	file	normalized path
- *	i)	path	path name for display
+ *	@param[in]	file	normalized path
+ *	@param[in]	path	path name for display
  */
 void
 put_include_anchor_direct(const char *file, const char *path)
@@ -532,8 +566,8 @@ put_include_anchor_direct(const char *file, const char *path)
 	strbuf_puts(outbuf, path);
 	strbuf_puts(outbuf, gen_href_end());
 }
-/*
- * Put a reserved word. (if, while, ...)
+/**
+ * Put a reserved word (@CODE{if}, @CODE{while}, ...)
  */
 void
 put_reserved_word(const char *word)
@@ -542,8 +576,8 @@ put_reserved_word(const char *word)
 	strbuf_puts(outbuf, word);
 	strbuf_puts(outbuf, reserved_end);
 }
-/*
- * Put a macro (#define,#undef,...) 
+/**
+ * Put a macro (@CODE{\#define}, @CODE{\#undef}, ...) 
  */
 void
 put_macro(const char *word)
@@ -552,7 +586,7 @@ put_macro(const char *word)
 	strbuf_puts(outbuf, word);
 	strbuf_puts(outbuf, sharp_end);
 }
-/*
+/**
  * Print warning message when unknown preprocessing directive is found.
  */
 void
@@ -563,7 +597,7 @@ unknown_preprocessing_directive(const char *word, int lineno)
 	if (colorize_warned_line)
 		warned = 1;
 }
-/*
+/**
  * Print warning message when unexpected eof.
  */
 void
@@ -573,8 +607,8 @@ unexpected_eof(int lineno)
 	if (colorize_warned_line)
 		warned = 1;
 }
-/*
- * Print warning message when unknown yacc directive is found.
+/**
+ * Print warning message when unknown @NAME{yacc} directive is found.
  */
 void
 unknown_yacc_directive(const char *word, int lineno)
@@ -583,7 +617,7 @@ unknown_yacc_directive(const char *word, int lineno)
 	if (colorize_warned_line)
 		warned = 1;
 }
-/*
+/**
  * Print warning message when unmatched brace is found.
  */
 void
@@ -593,10 +627,12 @@ missing_left(const char *word, int lineno)
 	if (colorize_warned_line)
 		warned = 1;
 }
-/*
+/**
  * Put a character with HTML quoting.
  *
- * If you want to put '<', '>' and '&', you should echoc() instead.
+ * @note If you want to put @CODE{'\<'}, @CODE{'\>'} or @CODE{'\&'}, you
+ * 		should echoc() instead, as this function escapes (fixes) those
+ *		characters for HTML.
  */
 void
 put_char(int c)
@@ -608,10 +644,12 @@ put_char(int c)
 	else
 		strbuf_putc(outbuf, c);
 }
-/*
+/**
  * Put a string with HTML quoting.
  *
- * If you want to put HTML tag itself, you should echoc() instead.
+ * @note If you want to put HTML tag itself, you should echos() instead,
+ *		as this function escapes (fixes) the characters @CODE{'\<'},
+ *		@CODE{'\>'} and @CODE{'\&'} for HTML.
  */
 void
 put_string(const char *s)
@@ -619,8 +657,8 @@ put_string(const char *s)
 	for (; *s; s++)
 		put_char(*s);
 }
-/*
- * Put brace ('{', '}')
+/**
+ * Put brace (@c '{', @c '}')
  */
 void
 put_brace(const char *text)
@@ -630,13 +668,15 @@ put_brace(const char *text)
 	strbuf_puts(outbuf, brace_end);
 }
 
-/*
- * common procedure for line control.
+/**
+ * @name common procedure for line control.
  */
+/** @{ */
 static char lineno_format[32];
 static const char *guide = NULL;
+/** @} */
 
-/*
+/**
  * Begin of line processing.
  */
 void
@@ -653,13 +693,14 @@ put_begin_of_line(int lineno)
                 guide = NULL;
         }
 }
-/*
+/**
  * End of line processing.
  *
- *	i)	lineno	current line number
- *	gi)	outbuf	HTML line image
+ *	@param[in]	lineno	current line number
+ *	@par Globals used (input):
+ *		@NAME{outbuf}, HTML line image
  *
- * The outbuf(string buffer) has HTML image of the line.
+ * The @EMPH{outbuf} (string buffer) has HTML image of the line. <br>
  * This function flush and clear it.
  */
 void
@@ -693,11 +734,11 @@ put_end_of_line(int lineno)
 	/* save for the other job in this module */
 	last_lineno = lineno;
 }
-/*
+/**
  * Encode URL.
  *
- *	o)	sb	encoded URL
- *	i)	url	URL
+ *	@param[out]	sb	encoded URL
+ *	@param[in]	url	URL
  */
 static void
 encode(STRBUF *sb, const char *url)
@@ -714,13 +755,13 @@ encode(STRBUF *sb, const char *url)
 		}
 	}
 }
-/*
- * get_cvs_module: return CVS module of source file.
+/**
+ * get_cvs_module: return @NAME{CVS} module of source file.
  *
- *	i)	file		source path
- *	o)	basename	If basename is not NULL, store pointer to
+ *	@param[in]	file		source path
+ *	@param[out]	basename	If @a basename is not @CODE{NULL}, store pointer to <br>
  *				the last component of source path.
- *	r)		!=NULL : relative path from repository top
+ *	@return		!=NULL : relative path from repository top <br>
  *			==NULL : CVS/Repository is not readable.
  */
 static const char *
@@ -757,13 +798,13 @@ get_cvs_module(const char *file, const char **basename)
 		return strbuf_value(module);
 	return NULL;
 }
-/*
+/**
  *
  * src2html: convert source code into HTML
  *
- *       i)      src   source file     - Read from
- *       i)      html  HTML file       - Write to
- *       i)      notsource 1: isn't source, 0: source.
+ *       @param[in]      src   source file     - Read from
+ *       @param[in]      html  HTML file       - Write to
+ *       @param[in]      notsource 1: isn't source, 0: source.
  */
 void
 src2html(const char *src, const char *html, int notsource)
