@@ -10,11 +10,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -39,13 +35,14 @@
 
 /* #include <machine/ansi.h>*/	/* for __offsetof */
 
-/*
+/**
+ * @file
  * This file defines five types of data structures: singly-linked lists,
  * singly-linked tail queues, lists, tail queues, and circular queues.
  *
  * A singly-linked list is headed by a single forward pointer. The elements
  * are singly linked for minimum space and pointer manipulation overhead at
- * the expense of O(n) removal for arbitrary elements. New elements can be
+ * the expense of @CODE{O(n)} removal for arbitrary elements. New elements can be
  * added to the list after an existing element or at the head of the list.
  * Elements being removed from the head of the list should use the explicit
  * macro for this purpose for optimum efficiency. A singly-linked list may
@@ -56,7 +53,7 @@
  * A singly-linked tail queue is headed by a pair of pointers, one to the
  * head of the list and the other to the tail of the list. The elements are
  * singly linked for minimum space and pointer manipulation overhead at the
- * expense of O(n) removal for arbitrary elements. New elements can be added
+ * expense of @CODE{O(n)} removal for arbitrary elements. New elements can be added
  * to the list after an existing element, at the head of the list, or at the
  * end of the list. Elements being removed from the head of the tail queue
  * should use the explicit macro for this purpose for optimum efficiency.
@@ -86,9 +83,9 @@
  * A circle queue may be traversed in either direction, but has a more
  * complex end of list detection.
  *
- * For details on the use of these macros, see the queue(3) manual page.
- *
+ * For details on the use of these macros, see the @XREF{queue,3} manual page.
  *
+ * @code{.txt}
  *			SLIST	LIST	STAILQ	TAILQ	CIRCLEQ
  * _HEAD		+	+	+	+	+
  * _ENTRY		+	+	+	+	+
@@ -106,15 +103,16 @@
  * _INSERT_TAIL		-	-	+	+	+
  * _REMOVE_HEAD		+	-	+	-	-
  * _REMOVE		+	+	+	+	+
- *
+ * @endcode
  */
 
-/*
+/**
  * Singly-linked List definitions.
  */
+/** @{ */
 #define SLIST_HEAD(name, type)						\
 struct name {								\
-	struct type *slh_first;	/* first element */			\
+	struct type *slh_first;	/**< first element */			\
 }
 
 #define SLIST_HEAD_INITIALIZER(head)					\
@@ -122,12 +120,14 @@ struct name {								\
  
 #define SLIST_ENTRY(type)						\
 struct {								\
-	struct type *sle_next;	/* next element */			\
+	struct type *sle_next;	/**< next element */			\
 }
+/** @} */
  
-/*
+/**
  * Singly-linked List functions.
  */
+/** @{ */
 #define	SLIST_EMPTY(head)	((head)->slh_first == NULL)
 
 #define	SLIST_FIRST(head)	((head)->slh_first)
@@ -167,14 +167,16 @@ struct {								\
 		    curelm->field.sle_next->field.sle_next;		\
 	}								\
 } while (0)
+/** @} */
 
-/*
+/**
  * Singly-linked Tail queue definitions.
  */
+/** @{ */
 #define STAILQ_HEAD(name, type)						\
 struct name {								\
-	struct type *stqh_first;/* first element */			\
-	struct type **stqh_last;/* addr of last next element */		\
+	struct type *stqh_first;/**< first element */			\
+	struct type **stqh_last;/**< addr of last next element */		\
 }
 
 #define STAILQ_HEAD_INITIALIZER(head)					\
@@ -182,12 +184,14 @@ struct name {								\
 
 #define STAILQ_ENTRY(type)						\
 struct {								\
-	struct type *stqe_next;	/* next element */			\
+	struct type *stqe_next;	/**< next element */			\
 }
+/** @} */
 
-/*
+/**
  * Singly-linked Tail queue functions.
  */
+/** @{ */
 #define STAILQ_EMPTY(head) ((head)->stqh_first == NULL)
 
 #define	STAILQ_INIT(head) do {						\
@@ -250,13 +254,15 @@ struct {								\
 			(head)->stqh_last = &(curelm)->field.stqe_next;	\
 	}								\
 } while (0)
+/** @} */
 
-/*
+/**
  * List definitions.
  */
+/** @{ */
 #define LIST_HEAD(name, type)						\
 struct name {								\
-	struct type *lh_first;	/* first element */			\
+	struct type *lh_first;	/**< first element */			\
 }
 
 #define LIST_HEAD_INITIALIZER(head)					\
@@ -264,14 +270,15 @@ struct name {								\
 
 #define LIST_ENTRY(type)						\
 struct {								\
-	struct type *le_next;	/* next element */			\
-	struct type **le_prev;	/* address of previous next element */	\
+	struct type *le_next;	/**< next element */			\
+	struct type **le_prev;	/**< address of previous next element */	\
 }
+/** @} */
 
-/*
+/**
  * List functions.
  */
-
+/** @{ */
 #define	LIST_EMPTY(head) ((head)->lh_first == NULL)
 
 #define LIST_FIRST(head)	((head)->lh_first)
@@ -313,14 +320,16 @@ struct {								\
 		    (elm)->field.le_prev;				\
 	*(elm)->field.le_prev = (elm)->field.le_next;			\
 } while (0)
+/** @} */
 
-/*
+/**
  * Tail queue definitions.
  */
+/** @{ */
 #define TAILQ_HEAD(name, type)						\
 struct name {								\
-	struct type *tqh_first;	/* first element */			\
-	struct type **tqh_last;	/* addr of last next element */		\
+	struct type *tqh_first;	/**< first element */			\
+	struct type **tqh_last;	/**< addr of last next element */		\
 }
 
 #define TAILQ_HEAD_INITIALIZER(head)					\
@@ -328,13 +337,15 @@ struct name {								\
 
 #define TAILQ_ENTRY(type)						\
 struct {								\
-	struct type *tqe_next;	/* next element */			\
-	struct type **tqe_prev;	/* address of previous next element */	\
+	struct type *tqe_next;	/**< next element */			\
+	struct type **tqe_prev;	/**< address of previous next element */	\
 }
+/** @} */
 
-/*
+/**
  * Tail queue functions.
  */
+/** @{ */
 #define	TAILQ_EMPTY(head) ((head)->tqh_first == NULL)
 
 #define TAILQ_FOREACH(var, head, field)					\
@@ -402,25 +413,29 @@ struct {								\
 		(head)->tqh_last = (elm)->field.tqe_prev;		\
 	*(elm)->field.tqe_prev = (elm)->field.tqe_next;			\
 } while (0)
+/** @} */
 
-/*
+/**
  * Circular queue definitions.
  */
+/** @{ */
 #define CIRCLEQ_HEAD(name, type)					\
 struct name {								\
-	struct type *cqh_first;		/* first element */		\
-	struct type *cqh_last;		/* last element */		\
+	struct type *cqh_first;		/**< first element */		\
+	struct type *cqh_last;		/**< last element */		\
 }
 
 #define CIRCLEQ_ENTRY(type)						\
 struct {								\
-	struct type *cqe_next;		/* next element */		\
-	struct type *cqe_prev;		/* previous element */		\
+	struct type *cqe_next;		/**< next element */		\
+	struct type *cqe_prev;		/**< previous element */		\
 }
+/** @} */
 
-/*
+/**
  * Circular queue functions.
  */
+/** @{ */
 #define CIRCLEQ_EMPTY(head) ((head)->cqh_first == (void *)(head))
 
 #define CIRCLEQ_FIRST(head) ((head)->cqh_first)
@@ -498,11 +513,13 @@ struct {								\
 		(elm)->field.cqe_prev->field.cqe_next =			\
 		    (elm)->field.cqe_next;				\
 } while (0)
+/** @} */
 
 #ifdef _KERNEL
 
 /*
- * XXX insque() and remque() are an old way of handling certain queues.
+ * @par XXX
+ * @NAME{insque()} and @NAME{remque()} are an old way of handling certain queues.
  * They bogusly assumes that all queue heads look alike.
  */
 
