@@ -1,27 +1,29 @@
 /*
- * Copyright (c) 2002, 2004, 2005
+ * Copyright (c) 2002, 2004, 2005, 2008
  *	Tama Communications Corporation
  *
  * This file is part of GNU GLOBAL.
  *
- * GNU GLOBAL is free software; you can redistribute it and/or modify
+ * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
- *
- * GNU GLOBAL is distributed in the hope that it will be useful,
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
+#ifdef STDC_HEADERS
+#include <stdlib.h>
+#endif
 #ifdef HAVE_STRING_H
 #include <string.h>
 #else
@@ -37,15 +39,17 @@ static int match_suffix_list(const char *, const char *);
 
 static STRBUF *active_map;
 
-/*
+/**
  * construct language map.
  *
- * copy string langmap and convert it to language map like this:
+ * copy string langmap (@a map) and convert it to language map like this:
  *
+ * @code{.txt}
  * langmap (string)	"c:.c.h,java:.java,cpp:.C.H"
  *	|
  *	v
  * language map		c\0.c.h\0java\0.java\0cpp\0.C.H\0
+ * @endcode
  */
 void
 setup_langmap(const char *map)
@@ -71,20 +75,31 @@ setup_langmap(const char *map)
 	/* strbuf_close(active_map); */
 }
 
-/*
- * decide the language of the suffix.
+/**
+ * decide the language of the @a suffix.
+ *
+ * @remark
+ * 		Though @FILE{*.h} files are shared by C and C++, @NAME{GLOBAL} treats them
+ * 		as C source files by default. If you set an environment variable
+ *		@FILE{GTAGSFORCECPP} then C++ parser will be invoked.
  */
 const char *
 decide_lang(const char *suffix)
 {
 	const char *lang, *list, *tail;
 
-	list = strbuf_value(active_map);
-	tail = list + strbuf_getlen(active_map);
-	lang = list;
+	/*
+	 * Though '*.h' files are shared by C and C++, GLOBAL treats them
+	 * as C source files by default. If you set an environment variable
+	 * 'GTAGS_FORCECPP' then C++ parser will be invoked.
+	 */
+	if (!strcmp(suffix, ".h") && getenv("GTAGSFORCECPP") != NULL)
+		return "cpp";
+	lang = strbuf_value(active_map);
+	tail = lang + strbuf_getlen(active_map);
 
 	/* check whether or not list includes suffix. */
-	while (list < tail) {
+	while (lang < tail) {
 		list = lang + strlen(lang) + 1;
 		if (match_suffix_list(suffix, list))
 			return lang;
@@ -94,18 +109,20 @@ decide_lang(const char *suffix)
 	return NULL;
 }
 
-/*
- * return true if suffix matches with one in suffix list.
+/**
+ * return true if the @a suffix matches with one in the @a list.
  */
 static int
 match_suffix_list(const char *suffix, const char *list)
 {
+	const char *p;
+
 	while (*list) {
-		if (locatestring(list, suffix, MATCH_AT_FIRST
+		if ((p = locatestring(list, suffix, MATCH_AT_FIRST
 #if defined(_WIN32) || defined(__DJGPP__)
 							     |IGNORE_CASE
 #endif
-									 ))
+			)) != NULL && (*p == '\0' || *p == '.'))
 			return 1;
 		for (list++; *list && *list != '.'; list++)
 			;
@@ -113,8 +130,8 @@ match_suffix_list(const char *suffix, const char *list)
 	return 0;
 }
 
-/*
- * make the suffixes value from langmap value.
+/**
+ * make suffix value from @a langmap value.
  */
 void
 make_suffixes(const char *langmap, STRBUF *sb)
